@@ -17,12 +17,13 @@
 #'   The order determines which of the columns of raw data are plotted on the x
 #'   (1) or y (2) axis. N.B. this will be deprecated in a future release, and
 #'   plotting order will be acheived at point of data-entry.
+#' @param ... additional arguments to be passed to \code{\link{addEllipse}}.
 #'   
 #' @return A series of convex hulls added to an existing plot.
 #' @export
 
 
-plotGroupHulls <- function(siber, plot.args = NULL, iso.order = c(1,2)) {
+plotGroupHulls <- function(siber, plot.args = NULL, iso.order = c(1,2), ...) {
   
   # iso.order used to specify which data goes on which axis.
   x <- iso.order[1]
