@@ -2,7 +2,9 @@
 #' covariance matrix
 #' 
 #' This function takes a covariance 2x2 matrix Sigma and returns various 
-#' metrics relating to the corresponding Standard Ellipse.
+#' metrics relating to the corresponding Standard Ellipse. The function is 
+#' limited to the 2-dimensional case, as many of the ancilliary summary 
+#' statistics are not defined for higher dimensions (e.g. eccentricity).
 #' 
 #' @section Note: This function is currently based on the eigenvalue and 
 #'   eigenvector approach which is more flexible for higher dimensional problems
@@ -14,10 +16,10 @@
 #' @return A list comprising the following metrics for summarising the Standard 
 #' Ellipse
 #' #' \itemize{
-#'    \item {SEA}{the Standard Ellise Area (not sample size corrected)}
-#'    \item {eccentricity}{a measure of the elongation of the ellipse.}
-#'    \item {a}{the length of the semi-major axis}
-#'    \item {b}{the length of the semi-minor axis}
+#'    \item {SEA}{ the Standard Ellise Area (not sample size corrected)}
+#'    \item {eccentricity}{ a measure of the elongation of the ellipse.}
+#'    \item {a}{ the length of the semi-major axis}
+#'    \item {b}{ the length of the semi-minor axis}
 #' }
 #' 
 #' @examples
@@ -36,23 +38,20 @@ sigmaSEA <- function(sigma){
   a <- sqrt(eig$values[1])
   b <- sqrt(eig$values[2])
   
-  # NB this is the line causing odd ellipses to be drawn occasionally
-  # I suspect there is an internal re-ordering of the axes going on 
-  # underlying this. This behaviour is similar to what Mike Fowler and I
-  # are struggling with in our linear system stability research.
-  #theta <- asin(eig$vectors[1,2]) # OLD LINE #
-  theta <- sign(sigma[1,2]) * asin(abs(eig$vectors[2,1])) # NEW LINE 11/07/2011
+  # As of v2.0.4 I have replaced the asin() line with atan which 
+  # returns the angle of correct sign due to the inclusion of the quotient
+  # of the vectors.
+  theta <- atan(eig$vectors[2,1] / eig$vectors[1,1])
   
   SEA <- pi*a*b
   
-  
-
 
   out <- list()
   out$SEA <- pi*a*b
   out$eccentricity <- sqrt(1-((b^2)/(a^2)))
   out$a <- a
   out$b <- b
+  out$theta <- theta
 
   return(out)
 }
\ No newline at end of file
